@@ -21,7 +21,7 @@ import os
 import shlex
 import sys
 from urllib.parse import urlparse
-from . import UnidentifiedError, DetailedFailure
+from . import UnidentifiedError, DetailedFailure, version_string
 from .buildlog import (
     InstallFixer,
     ExplainInstallFixer,
@@ -94,7 +94,10 @@ def determine_fixers(session, resolver, explain=False):
 def main():  # noqa: C901
     import argparse
 
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(prog='ogni')
+    parser.add_argument(
+        "--version", action="version", version="%(prog)s " + version_string
+    )
     parser.add_argument(
         "--directory", "-d", type=str, help="Directory for project.", default="."
     )
@@ -271,7 +274,21 @@ def main():  # noqa: C901
 
         except ExplainInstall as e:
             display_explain_commands(e.commands)
-        except (UnidentifiedError, DetailedFailure):
+        except UnidentifiedError:
+            logging.info(
+                'If there is a clear indication of a problem in the build log, '
+                'please consider filing a request to update the patterns in '
+                'buildlog-consultant at '
+                'https://github.com/jelmer/buildlog-consultant/issues/new')
+            return 1
+        except DetailedFailure:
+            if not args.verbose:
+                logging.info(
+                    'Run with --verbose to get more information about steps taken '
+                    'to try to resolve error')
+            logging.info(
+                'Please consider filing a bug report at '
+                'https://github.com/jelmer/ognibuild/issues/new')
             return 1
         except NoBuildToolsFound:
             logging.info("No build tools found.")
