@@ -28,6 +28,7 @@ from buildlog_consultant.common import (
     MissingCHeader,
     MissingPkgConfig,
     MissingCommand,
+    MissingCommandOrBuildFile,
     MissingFile,
     MissingJavaScriptRuntime,
     MissingSprocketsFile,
@@ -46,6 +47,7 @@ from buildlog_consultant.common import (
     MissingSetupPyCommand,
     MissingJavaClass,
     MissingCSharpCompiler,
+    MissingRustCompiler,
     MissingRPackage,
     MissingRubyFile,
     MissingAutoconfMacro,
@@ -70,6 +72,7 @@ from buildlog_consultant.common import (
     MissingStaticLibrary,
     MissingGnulibDirectory,
     MissingLuaModule,
+    MissingPHPExtension,
 )
 
 from . import OneOfRequirement
@@ -119,6 +122,7 @@ from .requirements import (
     StaticLibraryRequirement,
     GnulibDirectoryRequirement,
     LuaModuleRequirement,
+    PHPExtensionRequirement,
 )
 from .resolver import UnsatisfiedRequirements
 
@@ -128,6 +132,8 @@ def problem_to_upstream_requirement(problem: Problem) -> Optional[Requirement]:
         return PathRequirement(problem.path)
     elif isinstance(problem, MissingCommand):
         return BinaryRequirement(problem.command)
+    elif isinstance(problem, MissingCommandOrBuildFile):
+        return BinaryRequirement(problem.command)
     elif isinstance(problem, MissingPkgConfig):
         return PkgConfigRequirement(problem.module, problem.minimum_version)
     elif isinstance(problem, MissingCHeader):
@@ -188,6 +194,8 @@ def problem_to_upstream_requirement(problem: Problem) -> Optional[Requirement]:
         ])
     elif isinstance(problem, MissingCSharpCompiler):
         return BinaryRequirement("msc")
+    elif isinstance(problem, MissingRustCompiler):
+        return BinaryRequirement("rustc")
     elif isinstance(problem, GnomeCommonMissing):
         return GnomeCommonRequirement()
     elif isinstance(problem, MissingGnulibDirectory):
@@ -237,6 +245,8 @@ def problem_to_upstream_requirement(problem: Problem) -> Optional[Requirement]:
         return PerlModuleRequirement(
             module=problem.module, filename=problem.filename, inc=problem.inc
         )
+    elif isinstance(problem, MissingPHPExtension):
+        return PHPExtensionRequirement(problem.extension)
     elif isinstance(problem, MissingPerlFile):
         return PerlFileRequirement(filename=problem.filename)
     elif isinstance(problem, MissingAutoconfMacro):
